@@ -3,7 +3,7 @@ use warnings;
 
 package Gentoo::MetaEbuild::Spec::Base;
 BEGIN {
-  $Gentoo::MetaEbuild::Spec::Base::VERSION = '0.1.1';
+  $Gentoo::MetaEbuild::Spec::Base::VERSION = '0.1.2';
 }
 
 # ABSTRACT: A Base Class for Gentoo MetaEbuild Specifications.
@@ -20,9 +20,10 @@ use MooseX::Types::Perl qw( VersionObject );
 use MooseX::Types::Path::Class qw( Dir File );
 use Scalar::Util qw( blessed );
 use MooseX::Has::Sugar;
-
 use version;
 
+use namespace::autoclean;
+
 class_has '_decoder' => (
   isa => CodeRef,
   ro, lazy_build,
@@ -88,17 +89,19 @@ sub _build__schema_creator {
 sub _opt_check {
   my ( $self, $opts ) = @_;
   if ( not exists $opts->{version} ) {
-    $opts->{version} = $self->_version->normal;
-    return $opts;
+    $opts->{version} = $self->_version;
+  } elsif( blessed $opts->{version} ){
+
+  } else {
+    $opts->{version} = version->parse( $opts->{version} );
   }
-  $opts->{version} = version->parse( $opts->{version} )->normal;
   return $opts;
 }
 
 sub _spec_file {
   my ( $self, $opts ) = @_;
   $opts = $self->_opt_check($opts);
-  return $self->_spec_dir->file( $opts->{version} . $self->_extension );
+  return $self->_spec_dir->file( $opts->{version}->normal . $self->_extension );
 }
 
 sub _spec_data {
@@ -110,14 +113,14 @@ sub _spec_data {
 sub _schema {
   my ( $self, $opts ) = @_;
   $opts = $self->_opt_check($opts);
-  return $self->_make_schema( $self->_spec_data, $opts );
+  return $self->_make_schema( $self->_spec_data($opts) );
 }
 
 
 sub check {
   my ( $self, $data, $opts ) = @_;
   $opts = $self->_opt_check($opts);
-  return $self->_schema->check($data);
+  return $self->_schema($opts)->check($data);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -134,7 +137,7 @@ Gentoo::MetaEbuild::Spec::Base - A Base Class for Gentoo MetaEbuild Specificatio
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 SYNOPSIS
 
